@@ -16,52 +16,52 @@ var languageNames = {
 "dz": "Dzongkha",
 "el": "Grecki",
 "en-GB": "Angielski (UK)",
-"en-ZA": "Angielski (SA)",
+"en-ZA": "Angielski (RPA)",
 "eo": "Esperanto",
-"es": "Hiszpański",
+"es": "Hszpański",
 "et": "Estoński",
 "eu": "Baskijski",
 "fi": "Fiński",
 "fr": "Francuski",
 "gl": "Galicyjski",
-"gu": "Gujarati",
+"gu": "Gudżarati",
 "he": "Hebrajski",
-"hi": "Hindi",
-"hr": "Croatian",
+"hi": "Hinduski",
+"hr": "Chorwacki",
 "hu": "Węgierski",
-"id": "Indonesian",
-"is": "Icelandic",
-"it": "Italian",
-"ja": "Japanese",
-"ka": "Georgian",
-"km": "Khmer",
-"ko": "Korean",
-"lo": "Lao",
-"lt": "Lithuanian",
-"lv": "Latvian",
-"mk": "Macedonian",
-"nb": "Norwegian Bokmål",
-"ne": "Nepali",
-"nl": "Dutch",
-"nn": "Norwegian Nynorsk",
+"id": "Indonezyjski",
+"is": "Islandzki",
+"it": "Włoski",
+"ja": "Japoński",
+"ka": "Gruziński",
+"km": "Khmerski",
+"ko": "Koreański",
+"lo": "Laotański",
+"lt": "Litewski",
+"lv": "Łotewski",
+"mk": "Macedoński",
+"nb": "Norweski (bokmål)",
+"ne": "Nepalski",
+"nl": "Holenderski",
+"nn": "Norweski (nynorsk)‎",
 "om": "Oromo",
 "pl": "Polski",
 "pt": "Portugalski",
 "pt-BR": "Portugalski brazylijski",
 "ro": "Rumuński",
-"ru": "Russian",
+"ru": "Rosyjski",
 "si": "Sinhala",
 "sid": "Sidama",
-"sk": "Slovak",
+"sk": "Słowacki",
 "sl": "Słoweński",
 "sq": "Albański",
 "sv": "Szwedzki",
-"ta": "Tamil",
-"tg": "Tajik",
-"tr": "Turkish",
-"ug": "Uyghur",
-"uk": "Ukrainian",
-"vi": "Vietnamese",
-"zh-CN": "Chiński (Uproszczony)",
-"zh-TW": "Chiński (Tradycyjny)",
+"ta": "Tamilski",
+"tg": "Tadżycki",
+"tr": "Turecki",
+"ug": "Ujgurski",
+"uk": "Ukraiński",
+"vi": "Wietnamski",
+"zh-CN": "Chiński (uproszczony)",
+"zh-TW": "Chiński (tradycyjny)",
 };
